/*
 * Displayable.java
 */

package catandmouse;

import java.awt.Graphics;
import java.awt.Rectangle;

/**
 * Something that takes up space, and knows how to draw itself on the screen.
 */
public interface Displayable {
    /**
     * Gets the bounds of this Displayable object.  This includes the top
     * left corner as well as the width and the height.
     * @return the bounds of the object as a Rectangle.
     */
    public Rectangle getBounds();
    
    /**
     * Sets the location of the <i>center</i> of the object.
     * @param x the horizontal coordinate of the Displayable's center
     * @param y the vertical coordinate of the Displayable's center
     */
    public void setLocation(int x, int y);
    
    /**
     * Draws the object onto the screen.  The Graphics has been set up
     * so that the top left corner of the object is at (0,0).
     * @param g a Graphics (actually a Graphics2D) to use for drawing.
     */
    public void paint(Graphics g);
}
