/*
 * World.java
 */

package catandmouse;

import java.awt.Point;
import java.awt.Rectangle;
import java.awt.geom.Ellipse2D;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

/**
 * The Model for the mouse environment.
 */
public class World {
    /** the mouse's home hole */
    private Hole hole;
    
    /** the mouse itself */
    private Mouse mouse;
    
    /** the cheese (the mouse's goal) */
    private Cheese cheese;
    
    /** the score, should you choose to use it */
    private int score;
    
    /** the list of displayable objects */
    private ArrayList displayables;
    
    /** Creates a new instance of World */
    public World() {
        initialize();
    }
    
    /**
     * Initialize all the model objects
     */
    public void initialize() {
        score = 0;
        mouse = new Mouse();
        cheese = new Cheese();
        hole = new Hole();
        displayables = new ArrayList();
        displayables.add(cheese);
        displayables.add(mouse);
        displayables.add(hole);
    }

    /**
     * Gets an Iterator over all the Displayable objects in the world.
     */
    public Iterator getDisplayables() {
        return displayables.iterator();
    }

    /**
     * Gets the Cheese object
     */
    public Cheese getCheese() {
        return cheese;
    }
    
    /**
     * Gets the Hole object
     */
    public Hole getHole() {
        return hole;
    }
    
    /**
     * Gets the mouse object
     */
    public Mouse getMouse() {
        return mouse;
    }
    
    /**
     * Gets the current score
     */
    public int getScore() {
        return score;
    }
    
    /**
     * Resets the score to zero
     */
    public void resetScore() {
        this.score = 0;
    }

    /**
     * Increments the score by a certain value
     * @param by the amount to increment the score (can be negative to
     * decrement the score
     */
    public void incrementScore(int by) {
        this.score += by;
    }
}
